==> qtjambi-location-debuginfo-macos-5.15.17.jar: sources/QtJambiLocation/QPlaceEditorial_shell.cpp <==
#include "QPlaceEditorial_shell.h"
#include <QtJambi/Cast>

void deleter_QPlaceEditorial(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPlaceEditorial")
    QPlaceEditorial *_ptr = reinterpret_cast<QPlaceEditorial *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QPlaceEditorial_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QPlaceEditorial_shell) ); }

jmethodID QPlaceEditorial_shell::__shell_javaMethod(int pos) const { return QPlaceEditorial_shell::__shell()->javaMethod(typeid(QPlaceEditorial), pos); }

// emitting (writeShellConstructor)
QPlaceEditorial_shell::QPlaceEditorial_shell()
    : QPlaceEditorial()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPlaceEditorial::QPlaceEditorial_shell()", QPlaceEditorial_shell::__shell())
    QPlaceEditorial_shell::__shell()->constructed(typeid(QPlaceEditorial));
}

QPlaceEditorial_shell::QPlaceEditorial_shell(const QPlaceContent& other0)
    : QPlaceEditorial(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPlaceEditorial::QPlaceEditorial_shell(const QPlaceContent& other0)", QPlaceEditorial_shell::__shell())
    QPlaceEditorial_shell::__shell()->constructed(typeid(QPlaceEditorial));
}

// emitting (writeShellDestructor)
QPlaceEditorial_shell::~QPlaceEditorial_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QPlaceEditorial::~QPlaceEditorial()", QPlaceEditorial_shell::__shell())
    QPlaceEditorial_shell::__shell()->destructed(typeid(QPlaceEditorial));
}

void QPlaceEditorial_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QPlaceEditorial_shell*>(ptr)->QPlaceEditorial_shell::__shell()->tryDeleteShell(typeid(QPlaceEditorial));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QPlaceEditorial()
void __qt_construct_QPlaceEditorial_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPlaceEditorial()")
    Q_UNUSED(__java_arguments)
    QPlaceEditorial *__qt_this = new(__qtjambi_ptr) QPlaceEditorial_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QPlaceEditorial(QPlaceContent)
void __qt_construct_QPlaceEditorial_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPlaceEditorial(QPlaceContent)")
    jobject other0 = __java_arguments[0].l;
    const QPlaceContent& __qt_other0 = qtjambi_cast<const QPlaceContent& >(__jni_env, other0);
    QPlaceEditorial *__qt_this = new(__qtjambi_ptr) QPlaceEditorial_shell(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QPlaceEditorial_shell
void __qt_destruct_QPlaceEditorial(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPlaceEditorial")
    reinterpret_cast<QPlaceEditorial_shell*>(ptr)->~QPlaceEditorial_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPlaceEditorial::QPlaceEditorial()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceEditorial_initialize_1native__Lio_qt_location_QPlaceEditorial_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPlaceEditorial::QPlaceEditorial()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPlaceEditorial_0, sizeof(QPlaceEditorial_shell), typeid(QPlaceEditorial), true, &deleter_QPlaceEditorial, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceEditorial::QPlaceEditorial(QPlaceContent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceEditorial_initialize_1native__Lio_qt_location_QPlaceEditorial_2Lio_qt_location_QPlaceContent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPlaceEditorial::QPlaceEditorial(QPlaceContent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPlaceEditorial_1, sizeof(QPlaceEditorial_shell), typeid(QPlaceEditorial), true, &deleter_QPlaceEditorial, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceEditorial::language()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceEditorial_language_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceEditorial *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceEditorial>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceEditorial::language()const", __qt_this)
        QString __qt_return_value = __qt_this->language();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPlaceEditorial::setLanguage(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceEditorial_setLanguage_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring data0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceEditorial *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceEditorial>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceEditorial::setLanguage(QString)", __qt_this)
        QString  __qt_data0 = qtjambi_cast<QString >(__jni_env, data0);
        __qt_this->setLanguage(__qt_data0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceEditorial::setText(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceEditorial_setText_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring text0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceEditorial *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceEditorial>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceEditorial::setText(QString)", __qt_this)
        QString  __qt_text0 = qtjambi_cast<QString >(__jni_env, text0);
        __qt_this->setText(__qt_text0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceEditorial::setTitle(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceEditorial_setTitle_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring data0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceEditorial *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceEditorial>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceEditorial::setTitle(QString)", __qt_this)
        QString  __qt_data0 = qtjambi_cast<QString >(__jni_env, data0);
        __qt_this->setTitle(__qt_data0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceEditorial::text()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceEditorial_text_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceEditorial *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceEditorial>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceEditorial::text()const", __qt_this)
        QString __qt_return_value = __qt_this->text();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPlaceEditorial::title()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceEditorial_title_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceEditorial *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceEditorial>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceEditorial::title()const", __qt_this)
        QString __qt_return_value = __qt_this->title();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceEditorial_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPlaceEditorial *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceEditorial>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPlaceEditorial(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QPlaceEditorial>("QPlaceEditorial", "io/qt/location/QPlaceEditorial");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPlaceEditorial, {
        ConstructorInfo(&__qt_construct_QPlaceEditorial_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QPlaceEditorial_1, "Lio/qt/location/QPlaceContent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPlaceEditorial);
    registerMetaType<QPlaceEditorial>("QPlaceEditorial");
    registerSizeOfShell(typeId, sizeof(QPlaceEditorial_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QPlaceContent, QPlaceEditorial>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-location-debuginfo-macos-5.15.20.jar: sources/QtJambiLocation/QPlaceEditorial_shell.cpp <==
#include "QPlaceEditorial_shell.h"
#include <QtJambi/Cast>

void deleter_QPlaceEditorial(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QPlaceEditorial")
    QPlaceEditorial *_ptr = reinterpret_cast<QPlaceEditorial *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QPlaceEditorial_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QPlaceEditorial_shell) ); }

jmethodID QPlaceEditorial_shell::__shell_javaMethod(int pos) const { return QPlaceEditorial_shell::__shell()->javaMethod(typeid(QPlaceEditorial), pos); }

// emitting (writeShellConstructor)
QPlaceEditorial_shell::QPlaceEditorial_shell()
    : QPlaceEditorial()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPlaceEditorial::QPlaceEditorial_shell()", QPlaceEditorial_shell::__shell())
    QPlaceEditorial_shell::__shell()->constructed(typeid(QPlaceEditorial));
}

QPlaceEditorial_shell::QPlaceEditorial_shell(const QPlaceContent& other0)
    : QPlaceEditorial(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPlaceEditorial::QPlaceEditorial_shell(const QPlaceContent& other0)", QPlaceEditorial_shell::__shell())
    QPlaceEditorial_shell::__shell()->constructed(typeid(QPlaceEditorial));
}

QPlaceEditorial_shell::QPlaceEditorial_shell(const QPlaceEditorial& other0)
    : QPlaceEditorial(other0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QPlaceEditorial::QPlaceEditorial_shell(const QPlaceEditorial& other0)", QPlaceEditorial_shell::__shell())
    QPlaceEditorial_shell::__shell()->constructed(typeid(QPlaceEditorial));
}

// emitting (writeShellDestructor)
QPlaceEditorial_shell::~QPlaceEditorial_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QPlaceEditorial::~QPlaceEditorial()", QPlaceEditorial_shell::__shell())
    QPlaceEditorial_shell::__shell()->destructed(typeid(QPlaceEditorial));
}

void QPlaceEditorial_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QPlaceEditorial_shell*>(ptr)->QPlaceEditorial_shell::__shell()->tryDeleteShell(typeid(QPlaceEditorial));
}

// emitting Virtual overrides (virtualFunctions)
// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QPlaceEditorial()
void __qt_construct_QPlaceEditorial(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPlaceEditorial()")
    Q_UNUSED(__java_arguments)
    QPlaceEditorial *__qt_this = new(__qtjambi_ptr) QPlaceEditorial_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QPlaceEditorial::QPlaceEditorial()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceEditorial_initialize_1native__Lio_qt_location_QPlaceEditorial_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPlaceEditorial::QPlaceEditorial()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPlaceEditorial, sizeof(QPlaceEditorial_shell), typeid(QPlaceEditorial), true, &deleter_QPlaceEditorial, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QPlaceEditorial(QPlaceContent)
void __qt_construct_QPlaceEditorial_cref_QPlaceContent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPlaceEditorial(QPlaceContent)")
    jobject other0 = __java_arguments[0].l;
    const QPlaceContent& __qt_other0 = qtjambi_cast<const QPlaceContent& >(__jni_env, other0);
    QPlaceEditorial *__qt_this = new(__qtjambi_ptr) QPlaceEditorial_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QPlaceEditorial::QPlaceEditorial(QPlaceContent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceEditorial_initialize_1native__Lio_qt_location_QPlaceEditorial_2Lio_qt_location_QPlaceContent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPlaceEditorial::QPlaceEditorial(QPlaceContent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPlaceEditorial_cref_QPlaceContent, sizeof(QPlaceEditorial_shell), typeid(QPlaceEditorial), true, &deleter_QPlaceEditorial, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QPlaceEditorial(QPlaceEditorial)
void __qt_construct_QPlaceEditorial_cref_QPlaceEditorial(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QPlaceEditorial(QPlaceEditorial)")
    jobject other0 = __java_arguments[0].l;
    const QPlaceEditorial& __qt_other0 = qtjambi_cast<const QPlaceEditorial& >(__jni_env, other0);
    QPlaceEditorial *__qt_this = new(__qtjambi_ptr) QPlaceEditorial_shell(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QPlaceEditorial::QPlaceEditorial(QPlaceEditorial)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceEditorial_initialize_1native__Lio_qt_location_QPlaceEditorial_2Lio_qt_location_QPlaceEditorial_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QPlaceEditorial::QPlaceEditorial(QPlaceEditorial)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QPlaceEditorial_cref_QPlaceEditorial, sizeof(QPlaceEditorial_shell), typeid(QPlaceEditorial), true, &deleter_QPlaceEditorial, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QPlaceEditorial_shell
void __qt_destruct_QPlaceEditorial(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QPlaceEditorial")
    reinterpret_cast<QPlaceEditorial_shell*>(ptr)->~QPlaceEditorial_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QPlaceEditorial::language()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceEditorial_language_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceEditorial *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceEditorial>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceEditorial::language()const", __qt_this)
        QString __qt_return_value = __qt_this->language();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPlaceEditorial::setLanguage(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceEditorial_setLanguage_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring data0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceEditorial *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceEditorial>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceEditorial::setLanguage(QString)", __qt_this)
        QString  __qt_data0 = qtjambi_cast<QString>(__jni_env, data0);
        __qt_this->setLanguage(__qt_data0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceEditorial::setText(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceEditorial_setText_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring text0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceEditorial *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceEditorial>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceEditorial::setText(QString)", __qt_this)
        QString  __qt_text0 = qtjambi_cast<QString>(__jni_env, text0);
        __qt_this->setText(__qt_text0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceEditorial::setTitle(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceEditorial_setTitle_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring data0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QPlaceEditorial *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceEditorial>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceEditorial::setTitle(QString)", __qt_this)
        QString  __qt_data0 = qtjambi_cast<QString>(__jni_env, data0);
        __qt_this->setTitle(__qt_data0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QPlaceEditorial::text()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceEditorial_text_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceEditorial *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceEditorial>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceEditorial::text()const", __qt_this)
        QString __qt_return_value = __qt_this->text();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QPlaceEditorial::title()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceEditorial_title_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QPlaceEditorial *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceEditorial>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QPlaceEditorial::title()const", __qt_this)
        QString __qt_return_value = __qt_this->title();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_location_QPlaceEditorial_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QPlaceEditorial *__qt_this = QtJambiAPI::objectFromNativeId<QPlaceEditorial>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QPlaceEditorial(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QPlaceEditorial>("QPlaceEditorial", "io/qt/location/QPlaceEditorial");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QPlaceEditorial, {
        ConstructorInfo(&__qt_construct_QPlaceEditorial, nullptr)
       ,ConstructorInfo(&__qt_construct_QPlaceEditorial_cref_QPlaceContent, "Lio/qt/location/QPlaceContent;")
       ,ConstructorInfo(&__qt_construct_QPlaceEditorial_cref_QPlaceEditorial, "Lio/qt/location/QPlaceEditorial;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QPlaceEditorial);
    registerMetaType<QPlaceEditorial>("QPlaceEditorial");
    registerSizeOfShell(typeId, sizeof(QPlaceEditorial_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QPlaceContent, QPlaceEditorial>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
